@@ -22,7 +22,7 @@ use HTML::TreeBuilder;
 use parent 'Exporter';
 our @EXPORT_OK = qw( sro sro_en sro_ok );
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 my $AGENT = 'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)';
 my $TIMEOUT = 30;
 
@@ -30,29 +30,45 @@ my $TIMEOUT = 30;
 my %siglas = (
   AL => 'AGENTES DE LEITURA',
   AR => 'AVISO DE RECEBIMENTO',
+  AS => 'ENCOMENDA PAC – AÇÃO SOCIAL',
   CA => 'OBJETO INTERNACIONAL',
+  CB => 'OBJETO INTERNACIONAL',
   CC => 'COLIS POSTAUX',
   CD => 'OBJETO INTERNACIONAL',
   CE => 'OBJETO INTERNACIONAL',
+  CF => 'OBJETO INTERNACIONAL',
   CG => 'OBJETO INTERNACIONAL',
+  CH => 'OBJETO INTERNACIONAL',
+  CI => 'OBJETO INTERNACIONAL',
   CJ => 'REGISTRADO INTERNACIONAL',
   CK => 'OBJETO INTERNACIONAL',
   CL => 'OBJETO INTERNACIONAL',
+  CM => 'OBJETO INTERNACIONAL',
+  CN => 'OBJETO INTERNACIONAL',
+  CO => 'OBJETO INTERNACIONAL',
   CP => 'COLIS POSTAUX',
+  CQ => 'OBJETO INTERNACIONAL',
   CR => 'CARTA REGISTRADA SEM VALOR DECLARADO',
   CS => 'OBJETO INTERNACIONAL',
   CT => 'OBJETO INTERNACIONAL',
+  CU => 'OBJETO INTERNACIONAL',
   CV => 'REGISTRADO INTERNACIONAL',
+  CW => 'OBJETO INTERNACIONAL',
+  CX => 'OBJETO INTERNACIONAL',
   CY => 'OBJETO INTERNACIONAL',
+  CZ => 'OBJETO INTERNACIONAL',
   DA => 'REM EXPRES COM AR DIGITAL',
   DB => 'REM EXPRES COM AR DIGITAL BRADESCO',
   DC => 'REM EXPRESSA CRLV/CRV/CNH e NOTIFICAÇÃO',
   DD => 'DEVOLUÇÃO DE DOCUMENTOS',
   DE => 'REMESSA EXPRESSA TALÃO E CARTÃO C/ AR',
+  DF => 'E-SEDEX (LÓGICO)',
   DI => 'REM EXPRES COM AR DIGITAL ITAU',
+  DL => 'ENCOMENDA SEDEX (LÓGICO)',
   DP => 'REM EXPRES COM AR DIGITAL PRF',
   DS => 'REM EXPRES COM AR DIGITAL SANTANDER',
   DT => 'REMESSA ECON.SEG.TRANSITO C/AR DIGITAL',
+  DX => 'ENCOMENDA SEDEX 10 (LÓGICO)',
   EA => 'OBJETO INTERNACIONAL',
   EB => 'OBJETO INTERNACIONAL',
   EC => 'ENCOMENDA PAC',
@@ -67,16 +83,19 @@ my %siglas = (
   EL => 'OBJETO INTERNACIONAL',
   EM => 'OBJETO INTERNACIONAL',
   EN => 'ENCOMENDA NORMAL NACIONAL',
+  EO => 'OBJETO INTERNACIONAL',
   EP => 'OBJETO INTERNACIONAL',
   EQ => 'ENCOMENDA SERVIÇO NÃO EXPRESSA ECT',
   ER => 'REGISTRADO',
-  ES => 'e-SEDEX',
-  EF => 'OBJETO INTERNACIONAL',
-  EG => 'OBJETO INTERNACIONAL',
-  EF => 'OBJETO INTERNACIONAL',
+  ES => 'E-SEDEX',
+  ET => 'OBJETO INTERNACIONAL',
   EU => 'OBJETO INTERNACIONAL',
   EV => 'OBJETO INTERNACIONAL',
+  EW => 'OBJETO INTERNACIONAL',
   EX => 'OBJETO INTERNACIONAL',
+  EY => 'OBJETO INTERNACIONAL',
+  EZ => 'OBJETO INTERNACIONAL',
+  FA => 'FAC REGISTRATO (LÓGICO)',
   FE => 'ENCOMENDA FNDE',
   FF => 'REGISTRADO DETRAN',
   FH => 'REGISTRADO FAC COM AR DIGITAL',
@@ -99,13 +118,17 @@ my %siglas = (
   JA => 'REMESSA ECONOMICA C/AR DIGITAL',
   JB => 'REMESSA ECONOMICA C/AR DIGITAL',
   JC => 'REMESSA ECONOMICA C/AR DIGITAL',
+  JD => 'REMESSA ECONOMICA C/AR DIGITAL',
+  JE => 'REMESSA ECONÔMICA C/AR DIGITAL',
+  JG => 'REGISTRATO AGÊNCIA (FÍSICO)',
   JJ => 'REGISTRADO JUSTIÇA',
+  JL => 'OBJETO REGISTRADO (LÓGICO)',
+  JM => 'MALA DIRETA POSTAL ESPECIAL (LÓGICO)',
+  LA => 'LOGÍSTICA REVERSA SIMULTÂNEA - ENCOMENDA SEDEX (AGÊNCIA)',
+  LB => 'LOGÍSTICA REVERSA SIMULTÂNEA - ENCOMENDA E-SEDEX (AGÊNCIA)',
   LC => 'CARTA EXPRESSA',
   LE => 'LOGÍSTICA REVERSA ECONOMICA',
-  LF => 'OBJETO INTERNACIONAL',
-  LI => 'OBJETO INTERNACIONAL',
-  LJ => 'OBJETO INTERNACIONAL',
-  LM => 'OBJETO INTERNACIONAL',
+  LP => 'LOGÍSTICA REVERSA SIMULTÂNEA - ENCOMENDA PAC (AGÊNCIA)',
   LS => 'LOGISTICA REVERSA SEDEX',
   LV => 'LOGISTICA REVERSA EXPRESSA',
   LX => 'CARTA EXPRESSA',
@@ -113,7 +136,6 @@ my %siglas = (
   MA => 'SERVIÇOS ADICIONAIS',
   MB => 'TELEGRAMA DE BALCÃO',
   MC => 'MALOTE CORPORATIVO',
-  MD => 'SEDEX MUNDI - DOCUMENTO INTERNO',
   ME => 'TELEGRAMA',
   MF => 'TELEGRAMA FONADO',
   MK => 'TELEGRAMA CORPORATIVO',
@@ -126,6 +148,11 @@ my %siglas = (
   NE => 'TELE SENA RESGATADA',
   PA => 'PASSAPORTE',
   PB => 'ENCOMENDA PAC - NÃO URGENTE',
+  PC => 'ENCOMENDA PAC A COBRAR',
+  PD => 'ENCOMENDA PAC - NÃO URGENTE',
+  PF => 'PASSAPORTE',
+  PG => 'ENCOMENDA PAC (ETIQUETA FÍSICA)',
+  PH => 'ENCOMENDA PAC (ETIQUETA LÓGICA)',
   PR => 'REEMBOLSO POSTAL - CLIENTE AVULSO',
   RA => 'REGISTRADO PRIORITÁRIO',
   RB => 'CARTA REGISTRADA',
@@ -146,20 +173,18 @@ my %siglas = (
   RQ => 'REGISTRADO AGÊNCIA',
   RR => 'CARTA REGISTRADA SEM VALOR DECLARADO',
   RS => 'REGISTRADO LÓGICO',
-  RT => 'REM ECON TALAO/CARTAO SEM AR DIGITA',
+  RT => 'REM ECON TALAO/CARTAO SEM AR DIGITAL',
   RU => 'REGISTRADO SERVIÇO ECT',
   RV => 'REM ECON CRLV/CRV/CNH COM AR DIGITAL',
-  RW => 'OBJETO INTERNACIONAL',
-  RX => 'OBJETO INTERNACIONAL',
   RY => 'REM ECON TALAO/CARTAO COM AR DIGITAL',
   RZ => 'REGISTRADO',
   SA => 'SEDEX ANOREG',
+  SB => 'SEDEX 10 AGÊNCIA (FÍSICO)',
   SC => 'SEDEX A COBRAR',
   SD => 'REMESSA EXPRESSA DETRAN',
   SE => 'ENCOMENDA SEDEX',
   SF => 'SEDEX AGÊNCIA',
   SG => 'SEDEX DO SISTEMA SARA',
-  RH => 'REGISTRADO COM AR DIGITAL',
   SI => 'SEDEX AGÊNCIA',
   SJ => 'SEDEX HOJE',
   SK => 'SEDEX AGÊNCIA',
@@ -174,7 +199,7 @@ my %siglas = (
   ST => 'REM EXPRES TALAO/CARTAO SEM AR DIGITAL',
   SU => 'ENCOMENDA SERVIÇO EXPRESSA ECT',
   SV => 'REM EXPRES CRLV/CRV/CNH COM AR DIGITAL',
-  SW => 'e-SEDEX',
+  SW => 'E-SEDEX',
   SX => 'SEDEX 10',
   SY => 'REM EXPRES TALAO/CARTAO COM AR DIGITAL',
   SZ => 'SEDEX AGÊNCIA',
@@ -185,7 +210,6 @@ my %siglas = (
   VD => 'ENCOMENDAS COM VALOR DECLARADO',
   VE => 'ENCOMENDAS',
   VF => 'ENCOMENDAS COM VALOR DECLARADO',
-  VV => 'OBJETO INTERNACIONAL',
   XM => 'SEDEX MUNDI',
   XR => 'ENCOMENDA SUR POSTAL EXPRESSO',
   XX => 'ENCOMENDA SUR POSTAL 24 HORAS',
